21.11 (2021-11-02)
------------------
- Fixed dataclass.unsafe_hash mapping to attrs.hash property `#7 <https://github.com/tefra/xsdata-attrs/issues/7>`_


21.8 (2021-08-03)
-----------------
- Initial Release
